#include "options.h"

bool verboseOption = FALSE;
bool ignoreErrorOption = FALSE;
bool debugOption = FALSE;
bool traceSectionOption = FALSE;
bool tracePushOption = FALSE;
bool traceStackOption = FALSE;
bool traceSourceOption = FALSE;
bool traceInstructionOption = FALSE;
bool transcriptOption = FALSE;
bool logOption = FALSE;
bool statusLineOption = TRUE;
bool regressionTestOption = FALSE;
